@@ -49,7 +49,7 @@ class matrix:
 		return matrix(res)
 
 	@property
-	def primaryDiagonalValues(self):
+	def primaryDiagonal(self):
 		res = []
 
 		for i in range(len(self.asList())):
@@ -60,7 +60,7 @@ class matrix:
 		return res
 
 	@property
-	def secondaryDiagonalValues(self):
+	def secondaryDiagonal(self):
 		order, res = self.order, []
 
 		for i in range(len(self.asList())):
@@ -254,7 +254,7 @@ def adjoint(matrix1):
 	if order[0] == 2:
 		return matrix([[matrix1[1][1], -matrix1[0][1]], [-matrix1[1][0], matrix1[0][0]]])
 	else:
-		res = [[((-1)**(i+j+2))*(matrix1[i][j])*(determinantOf(matrix1.minorOfValueAt(i+1, j+1))) for j in range(order[1])] for i in range(order[0])]
+		res = [[((-1)**(i+j+2))*(matrix1[i][j])*(determinant(matrix1.minorOfValueAt(i+1, j+1))) for j in range(order[1])] for i in range(order[0])]
 
 		return matrix(res)
 
@@ -276,8 +276,8 @@ def createRowMatrix(values):
 
 	return matrix([[i for i in values]])
 
-def determinantOf(matrix):
-	"""Returns the determinantOf of matrix"""
+def determinant(matrix):
+	"""Returns the determinant of matrix"""
 
 	order = matrix.order
 
@@ -287,18 +287,18 @@ def determinantOf(matrix):
 		elif order[0] == 2:
 			return (matrix[1][1]*matrix[0][0]) - (matrix[1][0]*matrix[0][1])
 		else:
-			M11 = matrix[0][0]*(determinantOf(matrix.minorOfValueAt(1, 1)))
-			M12 = matrix[0][1]*(determinantOf(matrix.minorOfValueAt(1, 2)))
-			M13 = matrix[0][2]*(determinantOf(matrix.minorOfValueAt(1, 3)))
+			M11 = matrix[0][0]*(determinant(matrix.minorOfValueAt(1, 1)))
+			M12 = matrix[0][1]*(determinant(matrix.minorOfValueAt(1, 2)))
+			M13 = matrix[0][2]*(determinant(matrix.minorOfValueAt(1, 3)))
 
 			return M11 - M12 + M13
 	else:
 		raise ValueError(f"can only find the determinant of square matrix, not '{order[0]}x{order[1]}' matrix.")
 
-def eigenvaluesOf(matrix):
+def eigenvalues(matrix):
 	"""Returns a list of the eigenvalues of the given matrix."""
 
-	order, S1 = matrix.order, sum(matrix.primaryDiagonalValues)
+	order, S1 = matrix.order, sum(matrix.primaryDiagonal)
 
 	assert (order[0] in (1, 2, 3)) and (order[1] in (1, 2, 3)), "Maximum Order is 3x3"
 
@@ -312,7 +312,7 @@ def eigenvaluesOf(matrix):
 		return ((g**2)/4+(f**3)/27)
 
 	if order[0] == 2:
-		S2 = determinantOf(matrix)
+		S2 = determinant(matrix)
 
 		a, b, c = 1, -S1, S2
 
@@ -320,8 +320,8 @@ def eigenvaluesOf(matrix):
 
 		return [(-b+disc)/(2*a), (-b-disc)/(2*a)]
 	elif order[0] == 3:
-		S2 = determinantOf(matrix.minorOfValueAt(1, 1))+determinantOf(matrix.minorOfValueAt(2, 2))+determinantOf(matrix.minorOfValueAt(3, 3))
-		S3 = determinantOf(matrix)
+		S2 = determinant(matrix.minorOfValueAt(1, 1))+determinant(matrix.minorOfValueAt(2, 2))+determinant(matrix.minorOfValueAt(3, 3))
+		S3 = determinant(matrix)
 
 		a, b, c, d = 1, -S1, S2, -S3
 
@@ -380,7 +380,7 @@ def eigenvaluesOf(matrix):
 
 			return [x1, compToInt(x2), compToInt(x3)]
 
-def eigenvectorsOf(matrix):
+def eigenvectors(matrix):
 	"""Generates the eigenvectors of the given matrix."""
 
 	res = []
@@ -395,7 +395,7 @@ def eigenvectorsOf(matrix):
 
 		return flag
 
-	evals, order = eigenvaluesOf(matrix), matrix.order
+	evals, order = eigenvalues(matrix), matrix.order
 	matobj = [_dc(matrix) for _ in range(order[0])]
 
 	for eigval in evals:
@@ -446,10 +446,10 @@ def eigenvectorsOf(matrix):
 	return res
 
 
-def inverseOf(matrix):
+def inverse(matrix):
 	"""Returns the inverse of matrix"""
 
-	det = determinantOf(matrix)
+	det = determinant(matrix)
 
 	if det != 0:
 		return adjoint(matrix)/det
@@ -561,7 +561,7 @@ def isScalar(matrix):
 def isSingular(matrix):
 	"""Returns True if matrix is a 'Singular Matrix' else Returns False"""
 
-	return True if determinantOf(matrix) == 0 else False
+	return True if determinant(matrix) == 0 else False
 
 def isSquare(matrix):
 	"""Returns True if matrix is a 'Square Matrix' else Returns False"""
